# OTLMOW-Template
## OTLMOW Project 
This project aims to implement the Flemish data standard OTL (https://wegenenverkeer.data.vlaanderen.be/) in Python.
It is split into different packages to reduce compatibility issues
- otlmow_model
- otlmow_modelbuilder
- otlmow_converter 
- otlmow_template (you are currently looking at this package)

## Installation and requirements
Currently, you need at least Python version 3.8 to use this library.

To install the OTL MOW project into your Python project, use pip to install it:
``` 
pip install otlmow_template
```
To upgrade an existing installation use:
``` 
pip install otlmow_template --upgrade
```

## Usage
#TODO